@@ -13,8 +13,8 @@ print(mcd.windows['minecraft:brewing_stand'])
 
 print(mcd.effects_name['Haste'])
 
-# Pocket Edition minecraft-data
-mcd_pe = minecraft_data("1.0", "pe")
+# Bedrock Edition minecraft-data
+mcd_pe = minecraft_data("1.0", "bedrock")
 
 print(mcd_pe.version)
 print(mcd_pe.find_item_or_block('stone'))
